| Python | Tests | Version | PyPI | Docs | License | Style
| --- | --- | --- | --- | --- | --- | --- |
| [![Python 3.7+](https://img.shields.io/badge/python-3.7+-blue.svg?logo=python&logoColor=white)](https://www.python.org/downloads/) | [![CI](https://github.com/exoclim/aeolus/workflows/tests/badge.svg)](https://github.com/exoclim/aeolus/actions?query=workflow%3Atests) | [![Conda Version](https://img.shields.io/conda/vn/conda-forge/aeolus.svg)](https://anaconda.org/conda-forge/aeolus) | [![PyPI](https://img.shields.io/pypi/v/aeolus.svg?logo=pypi&logoColor=white)](https://pypi.org/project/aeolus/) | [![Documentation](https://img.shields.io/badge/docs-latest-green?logo=github)](https://exoclim.github.io/aeolus) | [![License: LGPL v3](https://img.shields.io/badge/License-LGPL%20v3-blue.svg?logo=gnu)](LICENSE) | [![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

# aeolus
Python library for the analysis and visualisation of climate model output, primarily the UK Met Office Unified Model.
It leverages the functionality of [iris](https://github.com/SciTools/iris) and has modules geared towards working with 3D general circulation models of planetary atmospheres.

The documentation is available [here](https://exoclim.github.io/aeolus).

Contributions are welcome.
